@@ -2,6 +2,8 @@ import os
 import pkg_resources
 from unittest import TestCase
 from cyvcf2 import VCF
+
+from vafator.ploidies import PloidyManager
 from vafator.annotator import Annotator
 import vafator.tests.utils as test_utils
 import time
@@ -152,6 +154,71 @@ class TestAnnotator(TestCase):
         self.assertTrue("normal_ac" in info_annotations)
         self.assertTrue("normal_dp" in info_annotations)
 
+        variant = test_utils._get_mutation_at_position(output_vcf, 'chr1', 1506035)
+        self.assertIsNotNone(variant)
+        self.assertEqual(variant.INFO['normal_ac'], 3)
+        self.assertEqual(variant.INFO['normal_dp'], 3)
+        self.assertEqual(variant.INFO['normal_af'], 1.0)
+        self.assertEqual(variant.INFO['normal_pu'], 1.0)
+        self.assertEqual(variant.INFO['normal_eaf'], 0.5)
+        self.assertEqual(variant.INFO['normal_mq'][0], 0)
+        self.assertEqual(variant.INFO['normal_mq'][1], 60.0)
+        self.assertEqual(variant.INFO['normal_bq'][0], 0)
+        self.assertEqual(variant.INFO['normal_bq'][1], 37.0)
+        self.assertEqual(variant.INFO['normal_pos'][0], 0)
+        self.assertEqual(variant.INFO['normal_pos'][1], 56.0)
+
+        variant = test_utils._get_mutation_at_position(output_vcf, 'chr1', 1509825)
+        self.assertIsNotNone(variant)
+        self.assertEqual(variant.INFO['normal_ac'], 13)
+        self.assertEqual(variant.INFO['normal_dp'], 20)
+        # these values are rounded to six digits inside the VCF, not sure why when read the representation is
+        # different...
+        self.assertEqual(round(variant.INFO['normal_af'], 5), 0.65)
+        self.assertEqual(round(variant.INFO['normal_pu'], 5), 0.94234)
+        self.assertEqual(variant.INFO['normal_eaf'], 0.5)
+        self.assertEqual(variant.INFO['normal_mq'][0], 60.0)
+        self.assertEqual(variant.INFO['normal_mq'][1], 60.0)
+        self.assertEqual(variant.INFO['normal_bq'][0], 37.0)
+        self.assertEqual(variant.INFO['normal_bq'][1], 35.0)
+        self.assertEqual(variant.INFO['normal_pos'][0], 31.0)
+        self.assertEqual(variant.INFO['normal_pos'][1], 41.0)
+
+        # this is a deletion
+        variant = test_utils._get_mutation_at_position(output_vcf, 'chr1', 1323143)
+        self.assertIsNotNone(variant)
+        self.assertEqual(variant.INFO['normal_ac'], 20)
+        self.assertEqual(variant.INFO['normal_dp'], 21)
+        # these values are rounded to six digits inside the VCF, not sure why when read the representation is
+        # different...
+        self.assertEqual(round(variant.INFO['normal_af'], 5), 0.95238)
+        self.assertEqual(round(variant.INFO['normal_pu'], 5), 1.0)
+        self.assertEqual(variant.INFO['normal_eaf'], 0.5)
+        self.assertEqual(variant.INFO['normal_mq'][0], 60.0)
+        self.assertEqual(variant.INFO['normal_mq'][1], 60.0)
+        self.assertEqual(variant.INFO['normal_bq'][0], 0.0)
+        self.assertEqual(variant.INFO['normal_bq'][1], 0.0)
+        self.assertEqual(variant.INFO['normal_pos'][0], 50.0)
+        self.assertEqual(variant.INFO['normal_pos'][1], 21.0)
+
+        # this is an insertion
+        variant = test_utils._get_mutation_at_position(output_vcf, 'chr1', 1935367)
+        self.assertIsNotNone(variant)
+        self.assertEqual(variant.INFO['normal_ac'], 1)
+        self.assertEqual(variant.INFO['normal_dp'], 2)
+        # these values are rounded to six digits inside the VCF, not sure why when read the representation is
+        # different...
+        self.assertEqual(round(variant.INFO['normal_af'], 5), 0.5)
+        self.assertEqual(round(variant.INFO['normal_pu'], 5), 0.75)
+        self.assertEqual(variant.INFO['normal_eaf'], 0.5)
+        self.assertEqual(variant.INFO['normal_mq'][0], 60.0)
+        self.assertEqual(variant.INFO['normal_mq'][1], 29.0)
+        self.assertEqual(variant.INFO['normal_bq'][0], 0.0)
+        self.assertEqual(variant.INFO['normal_bq'][1], 0.0)
+        self.assertEqual(variant.INFO['normal_pos'][0], 95.0)
+        self.assertEqual(variant.INFO['normal_pos'][1], 56.0)
+
+
     def test_annotator_bams_order(self):
         input_file = pkg_resources.resource_filename(__name__, "resources/test1.vcf")
         output_vcf = pkg_resources.resource_filename(__name__, "resources/results/test_annotator1_output.vcf")
@@ -171,3 +238,43 @@ class TestAnnotator(TestCase):
         for v, v2 in zip(vcf, vcf_2):
             self.assertEqual(v.INFO["normal_dp"], v2.INFO["normal_dp"])
             self.assertEqual(v.INFO["tumor_dp"], v2.INFO["tumor_dp"])
+
+    def test_annotator_with_purities(self):
+        input_file = pkg_resources.resource_filename(__name__, "resources/test1.vcf")
+        output_vcf = pkg_resources.resource_filename(__name__, "resources/results/test_annotator1_output.vcf")
+        bam1 = pkg_resources.resource_filename(__name__, "resources/COLO_829_n1.bam")
+        bam2 = pkg_resources.resource_filename(__name__, "resources/COLO_829_t1.bam")
+        annotator = Annotator(
+            input_vcf=input_file, output_vcf=output_vcf, input_bams={"normal": [bam1], "tumor": [bam2]},
+            purities={"tumor": 0.8}, tumor_ploidies={"tumor": PloidyManager(genome_wide_ploidy=2.8)}
+        )
+        annotator.run()
+
+        self.assertTrue(os.path.exists(output_vcf))
+        n_variants_input = test_utils._get_count_variants(input_file)
+        n_variants_output = test_utils._get_count_variants(output_vcf)
+        self.assertTrue(n_variants_input == n_variants_output)
+
+        info_annotations = test_utils._get_info_fields(output_vcf)
+        self.assertTrue("tumor_af" in info_annotations)
+        self.assertTrue("normal_af" in info_annotations)
+        self.assertTrue("tumor_ac" in info_annotations)
+        self.assertTrue("normal_ac" in info_annotations)
+        self.assertTrue("tumor_dp" in info_annotations)
+        self.assertTrue("normal_dp" in info_annotations)
+        self.assertTrue("tumor_pu" in info_annotations)
+        self.assertTrue("normal_pu" in info_annotations)
+        self.assertTrue("normal_eaf" in info_annotations)
+        self.assertTrue("tumor_eaf" in info_annotations)
+        self.assertTrue("tumor_pw" in info_annotations)
+        self.assertTrue("normal_pw" in info_annotations)
+        self.assertTrue("tumor_bq" in info_annotations)
+        self.assertTrue("normal_bq" in info_annotations)
+        self.assertTrue("tumor_mq" in info_annotations)
+        self.assertTrue("normal_mq" in info_annotations)
+
+        annotator = Annotator(
+            input_vcf=input_file, output_vcf=output_vcf, input_bams={"normal": [bam1], "tumor": [bam2]},
+            purities={"tumor": 0.2}, tumor_ploidies={"tumor": PloidyManager(genome_wide_ploidy=1.5)}
+        )
+        annotator.run()
